@@ -8,7 +8,7 @@ ui.page_general_analysis <- function() {
   #   #          ui.sg.pancan.analysis("sg.pancan.analysis"))
   # )
   tabPanel(
-    title = "General Analysis",
+    title = "General Dataset Analysis",
     icon = icon("angle-double-down"),
     fluidRow(
       column(
@@ -28,9 +28,10 @@ ui.page_general_analysis <- function() {
         )
       ),
       column(
-        1,
+        1, offset = 1,
         dropdownButton(
           inputId = "ga_drop_button_custom_data",
+          label = "Upload your data?",
           tags$h3("Upload your data file"),
           br(),
           
@@ -58,7 +59,7 @@ ui.page_general_analysis <- function() {
         )
       ),
       column(4,
-        offset = 5,
+        offset = 4,
         shinyWidgets::actionBttn(
           inputId = "use_ga_page",
           label = "How to use",
@@ -87,6 +88,10 @@ ui.page_general_analysis <- function() {
       tabPanel(
         "Survival-Analysis",
         ui.modules_ga_surv_analysis("module_ga_surv_analysis")
+      ),
+      tabPanel(
+        "Dimension-Distribution",
+        ui.modules_ga_dim_distribution("module_ga_dim_distribution")
       )
     )
   )
